@@ -292,7 +292,7 @@ class PDFReader(PDFObjectReader, cos.Document):
         self.id = trailer['ID'] if 'ID' in trailer else None
         self._max_identifier_in_file = int(trailer['Size']) - 1
         self.catalog = trailer['Root']
-        self.dests = {}
+        self.dests = cos.Dictionary()
         try:
             dests_names = iter(self.catalog['Names']['Dests']['Names'])
             for name in dests_names:
@@ -432,6 +432,41 @@ class PDFReader(PDFObjectReader, cos.Document):
             offset -= 1
         return int(xref_offset)
 
+    def iter_outlines(self, depth=float('+inf')):
+        """Iterate over the outline entries up to a given depth
+
+        Args:
+            depth (int): the maximum depth of outline entries to yield
+
+        Returns:
+            Iterator[(int, String, Array)]: entry depth, title and destination
+
+        """
+        try:
+            outlines = self.catalog['Outlines']
+            entry = outlines['First']
+        except KeyError:
+            return
+        stack = [outlines]
+        while True:
+            entry_depth = len(stack) - 1
+            dest = entry['Dest']
+            yield (entry_depth, entry['Title'],
+                   dest if isinstance(dest, cos.Array) else self.dests[dest])
+            if 'First' in entry and depth > entry_depth:
+                stack.append(entry)
+                entry = entry['First']
+            elif 'Next' in entry:
+                entry = entry['Next']
+            else:
+                while stack:
+                    parent = stack.pop()
+                    if 'Next' in parent:
+                        entry = parent['Next']
+                        break
+                else:
+                    break
+
 
 class XRefTable(dict):
     def __init__(self, document, prev=None):
