@@ -24,12 +24,15 @@ from pathlib import Path
 
 import datetime
 import pickle
+import re
 import sys
 import time
 
 from collections import OrderedDict
+from contextlib import suppress
 from copy import copy
 from itertools import count
+from os import getenv
 
 from . import __version__, __release_date__
 from .attribute import OptionSet, Source
@@ -39,9 +42,11 @@ from .language import EN
 from .layout import (Container, ReflowRequired,
                      BACKGROUND, CONTENT, HEADER_FOOTER)
 from .number import format_number
+from .reference import ReferenceType
 from .strings import Strings
 from .style import StyleLog
-from .util import RefKeyDictionary
+from .text import StyledText
+from .util import DEFAULT, RefKeyDictionary
 from .warnings import warn
 
 
@@ -243,6 +248,7 @@ class Document(object):
         self._glossary = {}
         self._glossary_first = {}
         self._unique_id = 0
+        self.title_targets = set()
         self.error = False
 
     def _print_version_and_license(self):
@@ -280,8 +286,15 @@ to the terms of the GNU Affero General Public License version 3.''')
         id_references = self.references.setdefault(id, {})
         id_references[reference_type] = value
 
-    def get_reference(self, id, reference_type):
-        return self.references[id][reference_type]
+    def get_reference(self, id, reference_type, default=DEFAULT):
+        if reference_type == ReferenceType.PAGE:
+            return self.page_references.get(id, 'XX')
+        try:
+            return self.references[id][reference_type]
+        except KeyError:
+            if default is DEFAULT:
+                raise
+            return default
 
     def set_glossary(self, term, definition):
         try:
@@ -350,21 +363,26 @@ to the terms of the GNU Affero General Public License version 3.''')
 
         fake_container = FakeContainer(self)
         prev_page_counts, prev_page_refs = self._load_cache(filename_root)
-        metadata_args = {key: self.get_metadata(key)
-                         for key in ('title', 'author')}
         try:
             self.document_tree.build_document(fake_container)
             self.prepare(fake_container)
+            for out_of_line_flowables in self.supporting_matter.values():
+                for flowable in out_of_line_flowables:
+                    flowable.prepare(fake_container)
+            backend_metadata = self._get_backend_metadata()
             self.page_elements.clear()
             self.part_page_counts = prev_page_counts
             self.page_references = prev_page_refs.copy()
             while True:
-                self.backend_document = self.backend.Document(self.CREATOR,
-                                                              **metadata_args)
+                self.backend_document = \
+                    self.backend.Document(self.CREATOR, **backend_metadata)
                 self.part_page_counts = self._render_pages()
                 if (self.part_page_counts == prev_page_counts
                         and self.page_references == prev_page_refs):
                     break
+                if getenv('RINOH_SINGLE_PASS', '0') != '0':
+                    print('Stopping after first rendering pass.')
+                    break
                 print('Not yet converged, rendering again...')
                 prev_page_counts = self.part_page_counts
                 prev_page_refs = self.page_references.copy()
@@ -415,7 +433,7 @@ to the terms of the GNU Affero General Public License version 3.''')
             if not section.show_in_toc(fake_container):
                 continue
             section_id = section.get_id(self, create=False)
-            section_number = self.get_reference(section_id, 'number')
+            section_number = self.get_reference(section_id, 'number', None)
             section_title = self.get_reference(section_id, 'title')
             if section.level > current_level:
                 if section.level != current_level + 1:
@@ -429,11 +447,25 @@ to the terms of the GNU Affero General Public License version 3.''')
                 for i in range(current_level - section.level):
                     parent = stack.pop()
             current = []
+            with suppress(AttributeError):
+                section_title = section_title.to_string(fake_container)
+            with suppress(AttributeError):
+                section_number = section_number.to_string(fake_container)
             item = (str(section_id), section_number, section_title, current)
             parent.append(item)
             current_level = section.level
         backend_document.create_outlines(sections)
 
+    def _get_backend_metadata(self):
+        """Transforms document metadata to sanitized plain text strings"""
+        result = {}
+        for key in (k for k in ('title', 'author') if k in self.metadata):
+            value = self.get_metadata(key)
+            if isinstance(value, StyledText):
+                value = value.to_string(None)
+            result[key] = re.sub(r"\s+", ' ', value.replace('\b', ''))
+        return result
+
     PROGRESS_TEMPLATE = \
         '\r{:3d}% [{}{}] ETA {:02d}:{:02d} ({:02d}:{:02d}) page {}'
     PROGRESS_BAR_WIDTH = 40
