@@ -21,7 +21,7 @@ from .. import (TreeNode, TreeNodeMeta, InlineNode, BodyNode, BodySubNode,
 __all__ = ['DocutilsNode', 'DocutilsInlineNode',
            'DocutilsBodyNode', 'DocutilsBodySubNode',
            'DocutilsGroupingNode', 'DocutilsDummyNode',
-           'ReStructuredTextReader']
+           'ReStructuredTextReader', 'from_doctree']
 
 
 class DocutilsNode(TreeNode, metaclass=TreeNodeMeta):
@@ -41,6 +41,18 @@ class DocutilsNode(TreeNode, metaclass=TreeNodeMeta):
     def node_location(node):
         return node.source, node.line, node.tagname
 
+    @property
+    def root(self):
+        node = self.node
+        while node.document is None:
+            node = node.parent  # https://sourceforge.net/p/docutils/bugs/410/
+        settings = node.document.settings
+        try:                    # Sphinx
+            sphinx_env = settings.env
+        except AttributeError:  # plain docutils
+            return Path(settings._source).parent
+        return Path(sphinx_env.srcdir)
+
     @property
     def _ids(self):
         return self.get('ids')
@@ -105,27 +117,24 @@ from . import nodes
 class DocutilsReader(Reader):
     parser_class = None
 
-    def parse(self, filename_or_file):
+    def parse(self, filename_or_file, **context):
         try:
-            filename = Path(filename_or_file)
-            settings_overrides = dict(input_encoding='utf-8')
-            doctree = publish_doctree(None, source_path=str(filename),
-                                      source_class=FileInput,
-                                      settings_overrides=settings_overrides,
-                                      parser=self.parser_class())
+            file, filename = None, Path(filename_or_file)
+            kwargs = dict(source_path=str(filename),
+                          settings_overrides=dict(input_encoding='utf-8'))
         except TypeError:
-            filename = getattr(filename_or_file, 'name', None)
-            doctree = publish_doctree(filename_or_file,
-                                      source_class=FileInput,
-                                      parser=self.parser_class())
-        return self.from_doctree(filename, doctree)
-
-    def from_doctree(self, filename, doctree):
-        mapped_tree = DocutilsNode.map_node(doctree.document)
-        flowables = mapped_tree.children_flowables()
-        return DocumentTree(flowables, source_file=Path(filename))
+            file, kwargs = filename_or_file, {}
+        doctree = publish_doctree(file, source_class=FileInput,
+                                  parser=self.parser_class(), **kwargs)
+        return from_doctree(doctree, **context)
 
 
 class ReStructuredTextReader(DocutilsReader):
     extensions = ('rst', )
     parser_class = ReStructuredTextParser
+
+
+def from_doctree(doctree, **context):
+    mapped_tree = DocutilsNode.map_node(doctree.document, **context)
+    flowables = mapped_tree.children_flowables()
+    return DocumentTree(flowables)
