@@ -383,7 +383,7 @@ class Line_Block(Paragraph):
 
     def process_content(self, style=None):
         lines = self._process_block(self)
-        return intersperse(lines, rt.Newline())
+        return rt.MixedStyledText(intersperse(lines, rt.Newline()))
 
 
 class Line(DocutilsInlineNode):
@@ -396,27 +396,25 @@ class Doctest_Block(DocutilsBodyNode):
 
 
 class Reference(DocutilsBodyNode, DocutilsInlineNode):
-    @property
-    def annotation(self):
-        if self.get('refid'):
-            return rt.NamedDestinationLink(self.get('refid'))
-        elif self.get('refuri'):
-            return rt.HyperLink(self.get('refuri'))
-
     def build_styled_text(self):
-        annotation = self.annotation
         content = self.process_content()
-        if annotation is None:
-            return rt.MixedStyledText(content, style='broken link')
-        style = ('external link' if annotation.type == 'URI'
-                 else 'internal link')
-        return rt.AnnotatedText(content, annotation, style=style)
+        if self.get('refid'):
+            return rt.Reference(self.get('refid'), custom_title=content)
+        elif self.get('refuri'):
+            content.annotation = rt.HyperLink(self.get('refuri'))
+            content.style = 'external link'
+        else:
+            content.style = 'broken link'
+        return content
 
     def build_flowable(self):
         children = self.getchildren()
         assert len(children) == 1
         image = self.image.flowable()
-        image.annotation = self.annotation
+        if self.get('refid'):
+            image.annotation = rt.NamedDestinationLink(self.get('refid'))
+        elif self.get('refuri'):
+            image.annotation = rt.HyperLink(self.get('refuri'))
         return image
 
 
@@ -461,11 +459,12 @@ class Substitution_Definition(DocutilsBodyNode):
 class Target(DocutilsBodyNode, DocutilsInlineNode):
     def build_styled_text(self):
         # TODO: what about refid?
+        content = self.process_content()
         try:
-            destination = rt.NamedDestination(*self._ids)
-            return rt.AnnotatedText(self.process_content(), destination)
+            content.annotation = rt.NamedDestination(*self._ids)
         except IndexError:
-            return self.process_content()   # TODO: use refname?
+            pass
+        return content
 
     def build_flowable(self):
         return rt.AnchorFlowable()
@@ -517,8 +516,7 @@ class Term(DocutilsInlineNode):
     def build_styled_text(self):
         content = self.process_content()
         if self._ids:
-            destination = rt.NamedDestination(*self._ids)
-            content = rt.AnnotatedText(content, destination)
+            content.annotation = rt.NamedDestination(*self._ids)
         return content
 
 
@@ -624,6 +622,14 @@ class Image(DocutilsBodyNode, DocutilsInlineNode):
 class Figure(DocutilsGroupingNode):
     grouped_flowables_class = rt.Figure
 
+    def flowables(self):
+        figure, = super().flowables()
+        if figure.id is None:   # docutils
+            image = figure.children[0]
+            figure.id = image.id
+            figure.secondary_ids = image.secondary_ids
+        yield figure
+
 
 class Caption(DocutilsBodyNode):
     def build_flowable(self):
@@ -676,20 +682,26 @@ class Table(DocutilsBodyNode):
         body = tgroup.tbody.get_table_section()
         align = self.get('align')
         width_string = self.get('width')
-        return rt.Table(body, head=head,
-                        align=None if align == 'default' else align,
-                        width=convert_quantity(width_string),
-                        column_widths=column_widths)
-
-    def flowables(self):
-        table, = super().flowables()
+        table = rt.Table(body, head=head,
+                         align=None if align == 'default' else align,
+                         width=convert_quantity(width_string),
+                         column_widths=column_widths)
         try:
             caption = rt.Caption(self.title.process_content())
-            table_with_caption = rt.TableWithCaption([caption, table])
-            table_with_caption.classes.extend(self.get('classes'))
-            yield table_with_caption
         except AttributeError:
-            yield table
+            return table
+        table_with_caption = rt.TableWithCaption([caption, table])
+        return table_with_caption
+
+    def flowables(self):
+        classes = self.get('classes')
+        flowable, = super(DocutilsBodyNode, self).flowables()
+        try:
+            caption, table = flowable.children
+        except AttributeError:
+            table = flowable
+        table.classes.extend(classes)
+        yield flowable
 
 
 class TGroup(DocutilsNode):
