@@ -180,8 +180,8 @@ class Container(object):
     def render(self, type, rerender=False):
         """Render the contents of this container to its canvas.
 
-        Note that the rendered contents need to be :meth:`place`d on the parent
-        container's canvas before they become visible."""
+        Note that the rendered contents need to be :meth:`place`\\ d on the
+        parent container's canvas before they become visible."""
         for child in self.children:
             child.render(type, rerender)
 
@@ -589,6 +589,8 @@ class Chain(FlowableTarget):
             self.flowables.flow(container, last_descender=None,
                                 state=self._state)
             # all flowables have been rendered
+            from .flowable import GroupedFlowablesState
+            self._state = GroupedFlowablesState(None, [])
             if container == self.last_container:
                 self._init_state()    # reset state for the next rendering loop
             self.done = True
