@@ -414,6 +414,7 @@ class Styled(DocumentElement, Configurable, metaclass=StyledMeta):
                                     self.style_class.__name__,
                                     style.__class__.__name__))
         self.style = style
+        self.annotation = None
         self.classes = []
 
     def __eq__(self, other):
@@ -470,6 +471,9 @@ class Styled(DocumentElement, Configurable, metaclass=StyledMeta):
     def fallback_to_parent(self, attribute):
         return isinstance(self.style, ParentStyle)
 
+    def get_annotation(self, container):
+        return self.annotation
+
     @cached
     def get_style(self, attribute, container):
         if isinstance(self.style, Style):
@@ -479,6 +483,11 @@ class Styled(DocumentElement, Configurable, metaclass=StyledMeta):
                 pass
         return self.get_config_value(attribute, container.document)
 
+    @property
+    def has_id(self):
+        """Filter selection on an ID of this :class:`Styled`"""
+        return HasID(self)
+
     @property
     def has_class(self):
         """Filter selection on a class of this :class:`Styled`"""
@@ -494,6 +503,14 @@ class Styled(DocumentElement, Configurable, metaclass=StyledMeta):
             self.parent.before_placing(container)
 
 
+class HasID(object):
+    def __init__(self, styled):
+        self.styled = styled
+
+    def __eq__(self, id):
+        return id == self.styled.id or id in self.styled.secondary_ids
+
+
 class HasClass(object):
     def __init__(self, styled):
         self.styled = styled
