@@ -1,13 +1,11 @@
 
-from .decoration import FrameStyle
 from .draw import LineStyle, ShapeStyle
 from .flowable import FlowableStyle, GroupedFlowablesStyle
 from .flowable import LabeledFlowableStyle
 from .number import LabelStyle
-from .number import NumberStyle, NumberedParagraphStyle
+from .number import NumberStyle
 from .paragraph import ParagraphStyle
 from .reference import NoteMarkerStyle
-from .structure import HeaderStyle, FooterStyle
 from .structure import HeadingStyle
 from .structure import HorizontalRuleStyle
 from .structure import ListStyle
