@@ -9,12 +9,8 @@ import pytest
 
 from pathlib import Path
 
-from sphinx.application import Sphinx
-from sphinx.util.docutils import docutils_namespace
+from helpers.regression import render_rst_file, render_sphinx_rst_file
 
-from rinoh.frontend.sphinx import nodes    # load Sphinx docutils nodes
-
-from regression import render_rst_file, OUTPUT_DIR
 
 RST_PATH = Path(__file__).parent / 'rst'
 
@@ -25,15 +21,9 @@ def collect_tests():
 
 
 @pytest.mark.parametrize('test_name', collect_tests())
-def test(test_name):
+def test_rst(test_name):
     rst_path = RST_PATH / (test_name + '.rst')
-    test_output_dir = OUTPUT_DIR / test_name
     if test_name.startswith('sphinx_'):
-        with docutils_namespace():
-            out_dir = str(test_output_dir)
-            Sphinx(srcdir=str(RST_PATH), confdir=None, outdir=out_dir,
-                   doctreedir=out_dir, buildername='dummy', status=None)
-            render_rst_file(rst_path, test_name, RST_PATH)
+        render_sphinx_rst_file(rst_path, test_name, RST_PATH)
     else:
         render_rst_file(rst_path, test_name, RST_PATH)
-
